You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@harmony.apache.org by mc...@apache.org on 2008/05/22 15:34:09 UTC

svn commit: r659108 [8/19] - in /harmony/enhanced/drlvm/trunk/vm: em/src/ gc_gen/src/common/ gc_gen/src/mark_compact/ gc_gen/src/mark_sweep/ gc_gen/src/semi_space/ gc_gen/src/trace_forward/ include/open/ interpreter/src/ jitrino/src/codegenerator/ jitr...

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfOpndManager.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfOpndManager.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfOpndManager.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfOpndManager.h Thu May 22 06:33:38 2008
@@ -45,12 +45,12 @@
 public:
                  RegStack();
 
-    int32        newInReg(int32);
-    int32        newOutReg(int32);
-    void         setLocRegSize(int32 locRegSize_)     { locRegSize = locRegSize_; }
-    int32        getInRegSize()                       { return inRegSize; }
-    int32        getLocRegSize()                      { return locRegSize; }
-    int32        getOutRegSize()                      { return outRegSize; }
+    I_32        newInReg(I_32);
+    I_32        newOutReg(I_32);
+    void         setLocRegSize(I_32 locRegSize_)     { locRegSize = locRegSize_; }
+    I_32        getInRegSize()                       { return inRegSize; }
+    I_32        getLocRegSize()                      { return locRegSize; }
+    I_32        getOutRegSize()                      { return outRegSize; }
     bool         isOutReg(RegOpnd*);
 
     //----------------------------------------------------------------------------//
@@ -74,9 +74,9 @@
     RegBitSet    spillBrMask;          // brs that can be used for spilling/filling
 
 protected:
-    int32        inRegSize;            // number of general registers used for in args passing
-    int32        locRegSize;           // number of general registers actually used in local area (including in args)
-    int32        outRegSize;           // number of general registers used for out args passing
+    I_32        inRegSize;            // number of general registers used for in args passing
+    I_32        locRegSize;           // number of general registers actually used in local area (including in args)
+    I_32        outRegSize;           // number of general registers used for out args passing
 };
 
 //========================================================================================//
@@ -112,24 +112,24 @@
 class MemStack {
 public:
            MemStack();
-    int32  newInSlot(int32);
-    int32  newLocSlot(DataKind);
-    int32  newOutSlot(int32);
+    I_32  newInSlot(I_32);
+    I_32  newLocSlot(DataKind);
+    I_32  newOutSlot(I_32);
 
     void   calculateOffset(RegOpnd*);
-    int32  calculateOffset(int32);
-    int32  getMemStackSize();
-    int32  getSavedBase();
+    I_32  calculateOffset(I_32);
+    I_32  getMemStackSize();
+    I_32  getSavedBase();
     
 protected:
-    int32  align(int32, int32);
+    I_32  align(I_32, I_32);
 
-    int32  locMemSize;        // size of memory stack area used for opnd spilling (bytes)
-    int32  outMemSize;        // size of memory stack area used for out args passing (bytes)
+    I_32  locMemSize;        // size of memory stack area used for opnd spilling (bytes)
+    I_32  outMemSize;        // size of memory stack area used for out args passing (bytes)
 
-    int32  inBase;            // first memory inArg offset
-    int32  locBase;           // first local memory opnd offset
-    int32  outBase;           // first memory outArg offset
+    I_32  inBase;            // first memory inArg offset
+    I_32  locBase;           // first local memory opnd offset
+    I_32  outBase;           // first memory outArg offset
 };
 
 //========================================================================================//
@@ -139,15 +139,15 @@
 class StackInfo {
 public:
            StackInfo();
-    int32  rpBak;           // gr num or stack offset containing return pointer (e.g. r33)
-    int32  prBak;           // gr num or stack offset containing predicate registers (e.g. r34)
-    int32  pfsBak;          // gr num or stack offset containing AR.PFS (e.g. r35)
-    int32  unatBak;         // gr num or stack offset containing AR.UNAT (e.g. r36)
-    int32  savedBase;       // mem stack offset of first saved gr (bytes)
-    uint32 savedGrMask;     // mask of preserved grs saved on stack
-    uint32 savedFrMask;     // mask of preserved frs saved on stack
-    uint32 savedBrMask;     // mask of preserved brs saved on stack
-    uint32 memStackSize;    // mem stack frame size (bytes)
+    I_32  rpBak;           // gr num or stack offset containing return pointer (e.g. r33)
+    I_32  prBak;           // gr num or stack offset containing predicate registers (e.g. r34)
+    I_32  pfsBak;          // gr num or stack offset containing AR.PFS (e.g. r35)
+    I_32  unatBak;         // gr num or stack offset containing AR.UNAT (e.g. r36)
+    I_32  savedBase;       // mem stack offset of first saved gr (bytes)
+    U_32 savedGrMask;     // mask of preserved grs saved on stack
+    U_32 savedFrMask;     // mask of preserved frs saved on stack
+    U_32 savedBrMask;     // mask of preserved brs saved on stack
+    U_32 memStackSize;    // mem stack frame size (bytes)
 };
 
 //========================================================================================//
@@ -163,12 +163,12 @@
     //----------------------------------------------------------------------------//
 
     Opnd           *newOpnd(OpndKind = OPND_INVALID);
-    RegOpnd        *newRegOpnd(OpndKind, DataKind, int32 = LOCATION_INVALID);
+    RegOpnd        *newRegOpnd(OpndKind, DataKind, I_32 = LOCATION_INVALID);
     Opnd           *newImm(int64 = 0);
     ConstantRef    *newConstantRef(Constant*, DataKind = DATA_CONST_REF);
     NodeRef        *newNodeRef(BbNode* = NULL);
     MethodRef      *newMethodRef(MethodDesc* = NULL);
-    Opnd           *newInArg(OpndKind, DataKind, uint32);
+    Opnd           *newInArg(OpndKind, DataKind, U_32);
     uint16         getFpArgsNum();
 
     //----------------------------------------------------------------------------//
@@ -196,9 +196,9 @@
     // Reg allocation support
     //----------------------------------------------------------------------------//
 
-    int32          newLocation(OpndKind, DataKind, RegBitSet, bool);
-    int32          newScratchReg(OpndKind, RegBitSet&);
-    int32          newPreservReg(OpndKind, RegBitSet&);
+    I_32          newLocation(OpndKind, DataKind, RegBitSet, bool);
+    I_32          newScratchReg(OpndKind, RegBitSet&);
+    I_32          newPreservReg(OpndKind, RegBitSet&);
     
     //----------------------------------------------------------------------------//
     // Compressed references

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfPrologEpilogGenerator.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfPrologEpilogGenerator.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfPrologEpilogGenerator.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfPrologEpilogGenerator.h Thu May 22 06:33:38 2008
@@ -62,7 +62,7 @@
     
     RegOpnd*      newStorage(DataKind, uint16);
     void          setRegUsage(RegOpnd*, bool);
-    int32         calculateLocRegSize();
+    I_32         calculateLocRegSize();
     void          printRegMasks();
 
     MemoryManager &mm;

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfRegisterAllocator.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfRegisterAllocator.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfRegisterAllocator.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfRegisterAllocator.h Thu May 22 06:33:38 2008
@@ -44,10 +44,10 @@
     void               assignLocations();
     
     void               assignLocation(RegOpnd*);
-    void               updateAllocSet(Opnd*, uint32, QpMask);
+    void               updateAllocSet(Opnd*, U_32, QpMask);
     void               checkCallSite(Inst*, QpMask);
     
-    void               checkCoalescing(uint32, Inst*);
+    void               checkCoalescing(U_32, Inst*);
     void               removeSameRegMoves();
 
     MemoryManager      &mm;

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfRuntimeInterface.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfRuntimeInterface.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfRuntimeInterface.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfRuntimeInterface.h Thu May 22 06:33:38 2008
@@ -36,8 +36,8 @@
 public:
     void           unwindStack(MethodDesc*, JitFrameContext*, bool) ;
     void           getGCRootSet(MethodDesc*, GCInterface*, const JitFrameContext*, bool);
-    uint32         getInlineDepth(InlineInfoPtr, uint32);
-    Method_Handle  getInlinedMethod(InlineInfoPtr, uint32, uint32);
+    U_32         getInlineDepth(InlineInfoPtr, U_32);
+    Method_Handle  getInlinedMethod(InlineInfoPtr, U_32, U_32);
     void           fixHandlerContext(MethodDesc*, JitFrameContext*, bool);
     void           *getAddressOfThis(MethodDesc*, const JitFrameContext*, bool);
     bool           recompiledMethodEvent(MethodDesc*, void*);
@@ -48,12 +48,12 @@
 protected:
 
     // getGCRootSet support
-    U_8*           findSafePoint(U_8*, uint32, uint64);
+    U_8*           findSafePoint(U_8*, U_32, uint64);
     void           enumerateRootSet(GCInterface*, const JitFrameContext*, U_8*);
-    void**         getContextValue(int32);
-    void           reportMptr(int32, int32);
-    void           reportBase(int32);
-    bool           isMptr(int32);
+    void**         getContextValue(I_32);
+    void           reportMptr(I_32, I_32);
+    void           reportBase(I_32);
+    bool           isMptr(I_32);
 
     GCInterface    *gcInterface;
     const JitFrameContext *context;

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfRuntimeSupport.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfRuntimeSupport.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfRuntimeSupport.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfRuntimeSupport.h Thu May 22 06:33:38 2008
@@ -126,7 +126,7 @@
 
     void                 makeRootSetInfo(Uint32Vector&);
     void                 writeSpInfo(Uint32Vector&, uint64, RegOpndVector&);
-    int32                toInt32(RegOpnd*);
+    I_32                toInt32(RegOpnd*);
 
     SafePointVector      safePoints;       // after buildRootSet() vector contains all safe points
     MptrDefMap           mptr2def;         //

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfSpillGen.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfSpillGen.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfSpillGen.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfSpillGen.h Thu May 22 06:33:38 2008
@@ -41,8 +41,8 @@
     void          spillInst(Inst* inst);
     RegOpnd       *spillOpnd(RegOpnd*, bool);
     void          resetSpillRegMasks();
-    int32         getAvailableSpillReg(OpndKind);
-    int32         getAvailableReg(RegBitSet&, int16);
+    I_32         getAvailableSpillReg(OpndKind);
+    I_32         getAvailableReg(RegBitSet&, int16);
     bool          containsStackOpnd(Inst*);
     void          printResult(InstVector&, uint16);
 
@@ -66,11 +66,11 @@
     InstVector    fillCode;       // buffer for fill insts to be inserted in node inst list
     InstVector    spillCode;      // buffer for spill insts to be inserted in node inst list
     
-    int32         outOffset;      // offset of the first mem out arg (bytes)
-    int32         locOffset;      // offset of the first mem local (bytes)
-    int32         psfOffset;      // offset of previous stack frame (bytes)
-    int32         inOffset;       // offset of the first mem in arg (bytes)
-    int32         maxOffset;      // first unavailable in current frame offset (bytes)
+    I_32         outOffset;      // offset of the first mem out arg (bytes)
+    I_32         locOffset;      // offset of the first mem local (bytes)
+    I_32         psfOffset;      // offset of previous stack frame (bytes)
+    I_32         inOffset;       // offset of the first mem in arg (bytes)
+    I_32         maxOffset;      // first unavailable in current frame offset (bytes)
     
     RegBitSet     spillGrMask;    // gr available for spilling (true - reg is available)
     RegBitSet     spillFrMask;    // fr available for spilling (true - reg is available)

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfType.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfType.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfType.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/codegenerator/ipf/include/IpfType.h Thu May 22 06:33:38 2008
@@ -199,7 +199,7 @@
 typedef StlVector< Inst* >              InstVector;
 typedef StlVector< Node* >              NodeVector;
 typedef StlVector< Edge* >              EdgeVector;
-typedef StlVector< uint32 >             Uint32Vector;
+typedef StlVector< U_32 >             Uint32Vector;
 typedef StlList< Inst* >                InstList;
 typedef StlList< Node* >                NodeList;
 typedef StlList< Edge* >                EdgeList;
@@ -210,7 +210,7 @@
 typedef StlMap< Inst*, RegOpndSet >     Inst2RegOpndSetMap;
 typedef StlMap< uint64, RegOpndSet >    Uint642RegOpndSetMap;
 typedef bitset< NUM_G_REG >             RegBitSet;
-typedef StlMultiMap <uint32, RegOpnd*, greater <uint32> > Int2OpndMap;
+typedef StlMultiMap <U_32, RegOpnd*, greater <U_32> > Int2OpndMap;
 
 typedef NodeVector::iterator            NodeIterator;
 typedef InstVector::iterator            InstIterator;
@@ -227,7 +227,7 @@
 
 typedef NodeList                        Chain;
 typedef StlList< Chain* >               ChainList;
-typedef StlMultiMap< uint32, Chain*, greater < uint32 > > ChainMap;
+typedef StlMultiMap< U_32, Chain*, greater < U_32 > > ChainMap;
 typedef Chain::iterator                 ChainIterator;
 typedef ChainList::iterator             ChainListIterator;
 typedef ChainMap::iterator              ChainMapIterator;

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/dynopt/EdgeProfiler.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/dynopt/EdgeProfiler.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/dynopt/EdgeProfiler.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/dynopt/EdgeProfiler.cpp Thu May 22 06:33:38 2008
@@ -41,11 +41,11 @@
 
 static bool isMethodTrivial( ControlFlowGraph& cfg );
 static void checkBCMapping( ControlFlowGraph& cfg );
-static uint32 computeCheckSum( MemoryManager& mm, IRManager& irm, const StlSet<Node*>& nodesToIgnore, bool bcLevel);
+static U_32 computeCheckSum( MemoryManager& mm, IRManager& irm, const StlSet<Node*>& nodesToIgnore, bool bcLevel);
 static bool calculateProbsFromProfile(MemoryManager& mm, ControlFlowGraph& fg, const Edges& edges, DominatorTree* dt, LoopTree* lt, EdgeMethodProfile* profile, bool bcLevelProfiling, const StlSet<Node*>& nodesToIgnore);
 static Node* selectNodeToInstrument(IRManager& irm, Edge* edge);
 static void selectEdgesToInstrument(MemoryManager& mm, IRManager& irm, Edges& result, const StlSet<Node*>& nodesToIgnore, bool bcLevel);
-static uint32 genKey( uint32 n, Edge* edge, bool bcLevel, bool debug);
+static U_32 genKey( U_32 n, Edge* edge, bool bcLevel, bool debug);
 static bool hasCatch( Node* node );
 static void selectNodesToIgnore(IRManager& irm, LoopTree* lt, StlSet<Node*>& result, bool bcLevel);
 
@@ -102,8 +102,8 @@
     StlSet<Node*> nodesToIgnore(mm);
     selectNodesToIgnore(irm, lt, nodesToIgnore, flags.bcLevelProfiling);
     //compute checksum first
-    uint32 _checkSum = computeCheckSum(mm, irm, nodesToIgnore, flags.bcLevelProfiling);
-    StlVector<uint32> counterKeys(mm);
+    U_32 _checkSum = computeCheckSum(mm, irm, nodesToIgnore, flags.bcLevelProfiling);
+    StlVector<U_32> counterKeys(mm);
     // Instrument method entry first.
     Node* entryNode = flowGraph.getEntryNode();
     entryNode->prependInst(instFactory.makeIncCounter(0));
@@ -119,18 +119,18 @@
         //compute edge-ids before CFG modification: edge-ids are part of CFG consistency check.
         for (Edges::const_iterator it = edgesToInstrument.begin(), end = edgesToInstrument.end(); it!=end; ++it) {
             Edge* edge = *it;
-            uint32 key = genKey((uint32)counterKeys.size() + 1, edge, flags.bcLevelProfiling, debug);
+            U_32 key = genKey((U_32)counterKeys.size() + 1, edge, flags.bcLevelProfiling, debug);
             assert( key != 0 );
             counterKeys.push_back(key);
         }
         // Now revisit all of the edges that need to be instrumented
         // and generate instrumentation code.
-        uint32 i = 0;
+        U_32 i = 0;
         for (Edges::const_iterator it = edgesToInstrument.begin(), end = edgesToInstrument.end(); it!=end; ++it, ++i) {
             Edge* edge = *it;
             Node* nodeToInstrument = selectNodeToInstrument(irm, edge);
             assert(nodeToInstrument!=NULL && nodeToInstrument->isBlockNode());
-            uint32 key = counterKeys[i];
+            U_32 key = counterKeys[i];
             Inst* incInst = instFactory.makeIncCounter( key );
             assert(((Inst*)nodeToInstrument->getFirstInst())->getOpcode() != Op_IncCounter );
             nodeToInstrument->prependInst(incInst);
@@ -146,7 +146,7 @@
     
     ProfilingInterface* pi = irm.getProfilingInterface();
     if (!pi->hasMethodProfile(ProfileType_Edge, md, JITProfilingRole_GEN)) {
-        pi->createEdgeMethodProfile(mm , md,  (uint32)counterKeys.size(),  counterKeys.empty()?NULL:(uint32*)&counterKeys.front(), _checkSum);
+        pi->createEdgeMethodProfile(mm , md,  (U_32)counterKeys.size(),  counterKeys.empty()?NULL:(U_32*)&counterKeys.front(), _checkSum);
     }
 
     irm.getCompilationInterface().unlockMethodData();
@@ -176,7 +176,7 @@
     ProfilingInterface* pi = irm.getProfilingInterface();
     bool edgeProfilerMode = pi->isProfilingEnabled(ProfileType_Edge, JITProfilingRole_USE);
     bool entryBackedgeProfilerMode = !edgeProfilerMode && pi->isProfilingEnabled(ProfileType_EntryBackedge, JITProfilingRole_USE);
-    uint32 entryCount = (edgeProfilerMode || entryBackedgeProfilerMode) ? pi->getProfileMethodCount(md) : 0;
+    U_32 entryCount = (edgeProfilerMode || entryBackedgeProfilerMode) ? pi->getProfileMethodCount(md) : 0;
     if (isMethodTrivial(flowGraph) || !edgeProfilerMode || entryCount == 0) { 
         // Annotate the CFG using static profiler heuristics.
         if (debug) {
@@ -200,10 +200,10 @@
     StlSet<Node*> nodesToIgnore(mm); //see instrumentation pass for comments
     selectNodesToIgnore(irm, lt, nodesToIgnore, flags.bcLevelProfiling);
 
-    uint32 cfgCheckSum = computeCheckSum(mm, irm, nodesToIgnore, flags.bcLevelProfiling);
+    U_32 cfgCheckSum = computeCheckSum(mm, irm, nodesToIgnore, flags.bcLevelProfiling);
 
     EdgeMethodProfile* edgeProfile = pi->getEdgeMethodProfile(mm, md);
-    uint32 profileCheckSum = edgeProfile->getCheckSum();
+    U_32 profileCheckSum = edgeProfile->getCheckSum();
     //assert(profileCheckSum == cfgCheckSum);
     if (cfgCheckSum == profileCheckSum) {
         // Start propagating the CFG from instrumented edges.
@@ -263,7 +263,7 @@
     if (debug) {
         Log::out()<<"Starting probs calculation" <<std::endl;
     }
-    uint32 entryCount = *profile->getEntryCounter();
+    U_32 entryCount = *profile->getEntryCounter();
  
     //1. assign default value to nodes and edges, this value is used for consistency checks latter
     StlVector<Node*> nodes(mm);
@@ -282,13 +282,13 @@
     
     //2.1 get freqs from profile
     StlVector<double> edgeFreqs(mm, fg.getMaxEdgeId(), -1);
-    uint32 n = 1;
+    U_32 n = 1;
     for (Edges::const_iterator it = pEdges.begin(), end = pEdges.end(); it!=end; ++it, ++n) {
         Edge* edge = *it;
-        uint32 key = genKey(n, edge, bcLevelProfiling, debug);
-        uint32* counterAddr = profile->getCounter(key);
+        U_32 key = genKey(n, edge, bcLevelProfiling, debug);
+        U_32* counterAddr = profile->getCounter(key);
         //assert(bcLevelProfiling || counterAddr!=NULL); -> TODO: hits in lazy resolution mode
-        uint32 freq = 0;
+        U_32 freq = 0;
         if (counterAddr == NULL) {
             if (!bcLevelProfiling) { //avoid crash, use static profiler for a method
                 return false;
@@ -506,7 +506,7 @@
 //
 // Compute the checksum contribution of the given Edge
 //
-static uint32 _computeCheckSum(Node* node, const StlSet<Node*>& nodesToIgnore, StlVector<bool>& flags, uint32 depth, bool debug) {
+static U_32 _computeCheckSum(Node* node, const StlSet<Node*>& nodesToIgnore, StlVector<bool>& flags, U_32 depth, bool debug) {
     assert(flags[node->getId()] == false);
     flags[node->getId()] = true;
     //node is removed from checksum calculation if 
@@ -515,10 +515,10 @@
     bool ignored = nodesToIgnore.find(node)!=nodesToIgnore.end();
     bool skipped = ignored || node->getOutDegree()==1
         || (node->isCatchBlock() && node->isEmpty()) || node->isDispatchNode() || node->isExitNode(); 
-    uint32 dSum = skipped ? 0 : depth;
-    uint32 childDepth = skipped ? depth : depth + 1;
+    U_32 dSum = skipped ? 0 : depth;
+    U_32 childDepth = skipped ? depth : depth + 1;
     const Edges& outEdges = node->getOutEdges();
-    uint32 childsSum = 0;
+    U_32 childsSum = 0;
     for (Edges::const_iterator it = outEdges.begin(), end = outEdges.end(); it!=end; ++it) {
         Edge* edge = *it;
         Node* childNode = edge->getTargetNode();
@@ -534,12 +534,12 @@
     return dSum+childsSum;
 }
 
-static uint32 computeCheckSum( MemoryManager& mm, IRManager& irm,  const StlSet<Node*>& nodesToIgnore, bool bcLevel) {
+static U_32 computeCheckSum( MemoryManager& mm, IRManager& irm,  const StlSet<Node*>& nodesToIgnore, bool bcLevel) {
     bool debug = Log::isEnabled();
     if (debug) {
         Log::out()<< "calculating checksum.." << std::endl;
     }
-    uint32 checkSum = 0;
+    U_32 checkSum = 0;
     if (!bcLevel) {
         ControlFlowGraph& cfg = irm.getFlowGraph();
         StlVector<bool> flags(mm, cfg.getMaxNodeId(), false);
@@ -772,8 +772,8 @@
     return true;
 }
 
-static uint32 genKey( uint32 pos, Edge* edge, bool bcLevel, bool debug)  {
-    uint32 key = 0;
+static U_32 genKey( U_32 pos, Edge* edge, bool bcLevel, bool debug)  {
+    U_32 key = 0;
     if (debug) {
         Log::out()<<"\t\t key for edge with id="<<edge->getId()<<" ("; FlowGraph::printLabel(Log::out(), edge->getSourceNode());
         Log::out() << "->"; FlowGraph::printLabel(Log::out(), edge->getTargetNode()); Log::out()<<") is ";Log::out().flush();
@@ -782,10 +782,10 @@
         uint16 bcBefore = edge->getSourceNode()->getNodeEndBCOffset();
         uint16 bcAfter  = edge->getTargetNode()->getNodeStartBCOffset();
         assert(bcBefore!=ILLEGAL_BC_MAPPING_VALUE && bcAfter!=ILLEGAL_BC_MAPPING_VALUE);
-        key = (((uint32)bcBefore)<<16) + bcAfter;
+        key = (((U_32)bcBefore)<<16) + bcAfter;
     } else {
         //TODO: this algorithm is not 100% effective: we can't rely on edges order in CFG
-        uint32 edgePos = 0;
+        U_32 edgePos = 0;
         const Edges& edges = edge->getSourceNode()->getOutEdges();
         for (Edges::const_iterator it = edges.begin(), end = edges.end(); it!=end; ++it) {
             Edge* outEdge = *it;

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/dynopt/StaticProfiler.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/dynopt/StaticProfiler.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/dynopt/StaticProfiler.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/dynopt/StaticProfiler.cpp Thu May 22 06:33:38 2008
@@ -269,7 +269,7 @@
     double profile_threshold = optimizerFlags.profile_threshold;
     if(optimizerFlags.use_average_threshold) {
         // Keep a running average of method counts.
-        static uint32 count = 0;
+        static U_32 count = 0;
         static double total = 0.0;
         count++;
         double methodFreq = flowGraph.getEntryNode()->getExecCount();
@@ -315,7 +315,7 @@
     Edge* falseEdge = c->node->getFalseEdge();
     Edge* trueEdge = c->node->getTrueEdge();
     double probLeft = 1.0;
-    uint32 edgesLeft = (uint32)edges.size();
+    U_32 edgesLeft = (U_32)edges.size();
     if (falseEdge == NULL || trueEdge == NULL) { // can't apply general heuristics.
         Edge* uncondEdge = c->node->getUnconditionalEdge();
         if (uncondEdge) {
@@ -642,7 +642,7 @@
     for (Nodes::const_iterator it = nodes.begin(), end = nodes.end(); it!=end; ++it) {
         Node* node = *it;
         double sumProb = 0;
-        uint32 nNotEstimated = 0;
+        U_32 nNotEstimated = 0;
         const Edges& outEdges = node->getOutEdges();
         for(Edges::const_iterator eit = outEdges.begin(), eend = outEdges.end(); eit!=eend; ++eit) {
             Edge* e = *eit;

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/dynopt/ValueProfiler.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/dynopt/ValueProfiler.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/dynopt/ValueProfiler.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/dynopt/ValueProfiler.cpp Thu May 22 06:33:38 2008
@@ -44,12 +44,12 @@
     InstFactory& instFactory = irm.getInstFactory();
     OpndManager& opndManager = irm.getOpndManager();
     TypeManager& typeManager = irm.getTypeManager();
-    StlVector<uint32> counterKeys(mm);
+    StlVector<U_32> counterKeys(mm);
     bool debug = Log::isEnabled();
     bool profileAbstractCalls =  getBoolArg("profile_abstract", false);
     bool profileAllVirtualCalls =  getBoolArg("profile_all_virtual", false);
 
-    uint32 key = 0;
+    U_32 key = 0;
 
     StlVector<Node*> nodes(mm);
     flowGraph.getNodesPostOrder(nodes); 
@@ -61,7 +61,7 @@
             Opnd* base = NULL;
             Opnd* tauNullChecked = NULL;
             Opnd* tauTypesChecked = NULL;
-            uint32 argOffset = 0;
+            U_32 argOffset = 0;
             bool isIntfCall = false;
             if(Devirtualizer::isGuardableVirtualCall(lastInst, methodInst, base, tauNullChecked, tauTypesChecked, argOffset, isIntfCall)) {
                 assert(methodInst && base && tauNullChecked && tauTypesChecked && argOffset);
@@ -97,18 +97,18 @@
                         continue;
                     }
                 }
-                key = (uint32)lastInst->getBCOffset();
+                key = (U_32)lastInst->getBCOffset();
                 assert(key != ILLEGAL_BC_MAPPING_VALUE);
                 assert(key != 0);
                 if (debug) {
-                    Log::out() << "Use call instruction bcOffset = " << (int32)key << std::endl;
+                    Log::out() << "Use call instruction bcOffset = " << (I_32)key << std::endl;
                 }
 
                 Opnd* indexOpnd = opndManager.createSsaTmpOpnd(typeManager.getInt32Type());
-                Inst* loadIndexInst = instFactory.makeLdConst(indexOpnd, (int32)key);
+                Inst* loadIndexInst = instFactory.makeLdConst(indexOpnd, (I_32)key);
                 counterKeys.push_back(key);
                 Opnd* valueOpnd = vtableInst->getDst();
-                const uint32 numArgs = 2;
+                const U_32 numArgs = 2;
                 Opnd* args[numArgs] = {indexOpnd, valueOpnd};
                 Inst* addValueInst = instFactory.makeJitHelperCall(opndManager.getNullOpnd(), AddValueProfileValue, NULL, NULL, numArgs, args);
                 addValueInst->setBCOffset(call->getBCOffset());
@@ -118,14 +118,14 @@
         }
     }
 
-    uint32 cc_size = (uint32)counterKeys.size();
+    U_32 cc_size = (U_32)counterKeys.size();
     if (cc_size == 0) return;
 
     irm.getCompilationInterface().lockMethodData();
     
     ProfilingInterface* pi = irm.getProfilingInterface();
     if (!pi->hasMethodProfile(ProfileType_Value, md, JITProfilingRole_GEN)) {
-        pi->createValueMethodProfile(mm , md,  cc_size,  (uint32*)&counterKeys.front());
+        pi->createValueMethodProfile(mm , md,  cc_size,  (U_32*)&counterKeys.front());
     }
 
     irm.getCompilationInterface().unlockMethodData();

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/arith_rt.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/arith_rt.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/arith_rt.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/arith_rt.cpp Thu May 22 06:33:38 2008
@@ -270,7 +270,7 @@
 // i64 ->
 // Workaround for bug in gcc 4.1.x. It doesn't clear upper half of the long
 // register when it returns value from rt_h_i64_2_i32
-int     __stdcall rt_h_i64_2_i32(int64 i)   { return (int32)(i & 0xffffffff); };
+int     __stdcall rt_h_i64_2_i32(int64 i)   { return (I_32)(i & 0xffffffff); };
 float   __stdcall rt_h_i64_2_flt(int64 i)   { return (float)i; };
 double  __stdcall rt_h_i64_2_dbl(int64 i)   { return (double)i; };
 // flt ->
@@ -280,7 +280,7 @@
         return 0;
     }
     return i<(double)INT_MIN ? 
-                    INT_MIN : (i>=(double)INT_MAX ? INT_MAX : (int32)i);
+                    INT_MIN : (i>=(double)INT_MAX ? INT_MAX : (I_32)i);
 }
 
 jlong   __stdcall rt_h_flt_2_i64(float i)

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/cg.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/cg.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/cg.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/cg.h Thu May 22 06:33:38 2008
@@ -108,14 +108,14 @@
  */
 struct ProfileCounterInfo  {
    //This field contains composite info on counter size (first byte) and offset (last 3 bytes)
-   uint32 offsetInfo;
+   U_32 offsetInfo;
    //Link to the basic block to calculate counter's offset after code layout
     BBInfo* bb;
     ProfileCounterInfo() : offsetInfo(0), bb(NULL){}
 
-    static uint32 getInstSize(uint32 offsetInfo) { return offsetInfo >> 24;}
-    static uint32 getInstOffset(uint32 offsetInfo) { return offsetInfo & 0x00FFFFFF;}
-    static uint32 createOffsetInfo(uint32 instSize, uint32 instOffset) {
+    static U_32 getInstSize(U_32 offsetInfo) { return offsetInfo >> 24;}
+    static U_32 getInstOffset(U_32 offsetInfo) { return offsetInfo & 0x00FFFFFF;}
+    static U_32 createOffsetInfo(U_32 instSize, U_32 instOffset) {
         assert(instSize<0xFF && instOffset<0xFFFFFF); 
         return (instSize<<24) | (instOffset);
     }

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/cg_br.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/cg_br.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/cg_br.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/cg_br.cpp Thu May 22 06:33:38 2008
@@ -223,7 +223,7 @@
     AR gr_tabl = valloc(jobj);
     movp(gr_tabl, DATA_SWITCH_TABLE | m_curr_inst->pc, m_bbinfo->start);
 #ifdef _EM64T_
-    // On EM64T, we operate with int32 value in a register, but the 
+    // On EM64T, we operate with I_32 value in a register, but the 
     // register will be used as 64 bit in address form - have to extend
     sx(Opnd(i64, val.reg()), Opnd(i32, val.reg()));
 #endif

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/cg_fld_arr.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/cg_fld_arr.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/cg_fld_arr.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/cg_fld_arr.cpp Thu May 22 06:33:38 2008
@@ -383,7 +383,7 @@
             void * inv_base = (void*)-(int_ptr)OBJ_BASE;
             movp(tmp, inv_base);
             alu(alu_add, Opnd(jobj, tmp), s0.as_opnd());
-            // store the resulting int32
+            // store the resulting I_32
             Opnd where32(i32, where.base(), where.disp(), 
                           where.index(), where.scale());
             mov(where32, Opnd(jobj, tmp)); //s0.as_opnd(i32));

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/cg_instr.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/cg_instr.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/cg_instr.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/cg_instr.cpp Thu May 22 06:33:38 2008
@@ -52,13 +52,13 @@
     movp(addr, m_p_backedge_counter);
     int off = 0;
 #endif
-    uint32 offset = (uint32)(m_codeStream.ip() - m_codeStream.data() - m_bbinfo->ipoff); //store offsets inside of BB now. Fix it to method's offset after code layout
+    U_32 offset = (U_32)(m_codeStream.ip() - m_codeStream.data() - m_bbinfo->ipoff); //store offsets inside of BB now. Fix it to method's offset after code layout
     //put number of nops to align counter instruction
     nop(NOPS_PER_COUNTER);
     alu(alu_add, Opnd(i32, addr, off), 1);
 
    //store information about profiling counters
-    uint32 new_offset = (uint32)(m_codeStream.ip() - m_codeStream.data() - m_bbinfo->ipoff);
+    U_32 new_offset = (U_32)(m_codeStream.ip() - m_codeStream.data() - m_bbinfo->ipoff);
     ProfileCounterInfo info;
     info.bb = m_bbinfo;
     info.offsetInfo = ProfileCounterInfo::createOffsetInfo(new_offset - offset, offset);

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/cg_meth.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/cg_meth.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/cg_meth.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/cg_meth.cpp Thu May 22 06:33:38 2008
@@ -271,7 +271,7 @@
     //    args)
     for (unsigned i = 0, local=0; i<m_ci.count(); i++, local++) {
         jtype jt = m_ci.jt(i);
-        // All values less than 32 bits get moved between methods as int32
+        // All values less than 32 bits get moved between methods as I_32
         if (jt<i32) {
             jt = i32;
         }
@@ -380,7 +380,7 @@
         if (is_set(DBG_TRACE_CG)) {dbg(";;>locals.gc_map\n");}
         Opnd reg(i32, valloc(i32));
         alu(alu_xor, reg, reg);
-        for (unsigned i=(uint32)locals_map.size(); i<locals_gc_size; i++) {
+        for (unsigned i=(U_32)locals_map.size(); i<locals_gc_size; i++) {
             st4(reg.reg(), m_base, voff(m_stack.info_gc_locals()+i*sizeof(int)));
         }
     }

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/compiler.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/compiler.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/compiler.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/compiler.cpp Thu May 22 06:33:38 2008
@@ -510,15 +510,15 @@
     //
     
     //register profiler counters  mapping info if present
-    std::vector<uint32> profiler_counters_vec; //will automatically be deleted on exit from this method
+    std::vector<U_32> profiler_counters_vec; //will automatically be deleted on exit from this method
     if (!m_profileCountersMap.empty()) {
-        m_infoBlock.num_profiler_counters = (uint32)m_profileCountersMap.size();
+        m_infoBlock.num_profiler_counters = (U_32)m_profileCountersMap.size();
         profiler_counters_vec.resize(m_infoBlock.num_profiler_counters, 0);
         m_infoBlock.profiler_counters_map = &profiler_counters_vec.front();
         for (size_t i =0; i<m_profileCountersMap.size(); i++) {
             ProfileCounterInfo& info = m_profileCountersMap[i];
-            uint32 offset = ProfileCounterInfo::getInstOffset(info.offsetInfo) + (info.bb->addr - m_vmCode);
-            uint32 offsetInfo = ProfileCounterInfo::createOffsetInfo(ProfileCounterInfo::getInstSize(info.offsetInfo), offset);
+            U_32 offset = ProfileCounterInfo::getInstOffset(info.offsetInfo) + (info.bb->addr - m_vmCode);
+            U_32 offsetInfo = ProfileCounterInfo::createOffsetInfo(ProfileCounterInfo::getInstSize(info.offsetInfo), offset);
             m_infoBlock.profiler_counters_map[i]=offsetInfo;
         }
     }

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/enc.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/enc.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/enc_ia32.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/enc_ia32.cpp Thu May 22 06:33:38 2008
@@ -675,7 +675,7 @@
     ip(EncoderBase::encode(ip(), mn, args));
 }
 
-void Encoder::nop_impl(uint32 n) 
+void Encoder::nop_impl(U_32 n) 
 {
     ip(EncoderBase::nops(ip(), n));
 }

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/jet.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/jet.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/jet.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/jet.cpp Thu May 22 06:33:38 2008
@@ -875,7 +875,7 @@
  * @return 0
  */
 extern "C" JITEXPORT
-uint32 JIT_get_inline_depth(JIT_Handle jit, InlineInfoPtr ptr, uint32 offset)
+U_32 JIT_get_inline_depth(JIT_Handle jit, InlineInfoPtr ptr, U_32 offset)
 {
     return 0;
 }
@@ -886,7 +886,7 @@
  */
 extern "C" JITEXPORT
 Method_Handle JIT_get_inlined_method(JIT_Handle jit, InlineInfoPtr ptr,
-                                     uint32 offset, uint32 inline_depth)
+                                     U_32 offset, U_32 inline_depth)
 {
     return 0;
 }
@@ -897,7 +897,7 @@
  */
 extern "C" JITEXPORT
 uint16 JIT_get_inlined_bc(JIT_Handle jit, InlineInfoPtr ptr,
-                                     uint32 offset, uint32 inline_depth)
+                                     U_32 offset, U_32 inline_depth)
 {
     return 0;
 }

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/mib.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/mib.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/mib.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/mib.cpp Thu May 22 06:33:38 2008
@@ -69,10 +69,10 @@
     rt_inst_addrs = (const char**)(to + get_hdr_size());
 
    //store information about profiling counters for the method in MethodInfoBlock
-    uint32* countersInfo = (uint32*)(to +  get_hdr_size() + get_bcmap_size());
+    U_32* countersInfo = (U_32*)(to +  get_hdr_size() + get_bcmap_size());
     countersInfo[0]=num_profiler_counters;
     if (num_profiler_counters > 0) {
-        memcpy(countersInfo+1, profiler_counters_map, num_profiler_counters * sizeof(uint32));
+        memcpy(countersInfo+1, profiler_counters_map, num_profiler_counters * sizeof(U_32));
     }
 }
 

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/mib.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/mib.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/mib.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/mib.h Thu May 22 06:33:38 2008
@@ -339,11 +339,11 @@
         
        // load profiling counters info
         char* countersInfo =  from + get_hdr_size() + get_bcmap_size();
-        num_profiler_counters = *(uint32*)countersInfo;
+        num_profiler_counters = *(U_32*)countersInfo;
 		if (num_profiler_counters > 0) {
-			profiler_counters_map = (uint32*)(countersInfo + sizeof(uint32));
+			profiler_counters_map = (U_32*)(countersInfo + sizeof(U_32));
 		}
-        profiler_counters_map = (uint32*)(countersInfo + sizeof(uint32));
+        profiler_counters_map = (U_32*)(countersInfo + sizeof(U_32));
     }
 
     /**
@@ -439,7 +439,7 @@
    *
    */
     unsigned get_profile_counters_map_size() const {
-        return sizeof (uint32) + num_profiler_counters * sizeof(uint32);
+        return sizeof (U_32) + num_profiler_counters * sizeof(U_32);
     }
 
     /**
@@ -569,11 +569,11 @@
    /**
    * Number of profile counters in the method
    */
-    uint32   num_profiler_counters;
+    U_32   num_profiler_counters;
    /**
    * Profiling counters information for patching: counter size and offset
    */
-    uint32*  profiler_counters_map;
+    U_32*  profiler_counters_map;
 };
 
 

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/rt.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/rt.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/rt.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/rt.cpp Thu May 22 06:33:38 2008
@@ -551,7 +551,7 @@
     unsigned * map = (unsigned*)(ebp + frame.info_gc_locals());
 
     uint64* var_ptr_to_64;
-    uint32* var_ptr_to32;
+    U_32* var_ptr_to32;
 
     switch(var_type) {
     case VM_DATA_TYPE_INT64:
@@ -572,8 +572,8 @@
         break;
 #endif
     default:
-        var_ptr_to32 = (uint32*)value_ptr;
-        *var_ptr_to32 = *(uint32*)(ebp + frame.local(var_num));
+        var_ptr_to32 = (U_32*)value_ptr;
+        *var_ptr_to32 = *(U_32*)(ebp + frame.local(var_num));
     }
     return EXE_ERROR_NONE;
 }
@@ -596,7 +596,7 @@
 
     char * ebp = (char*)**devirt(bp, context);
     uint64* var_ptr_to_64;
-    uint32* var_ptr_to32;
+    U_32* var_ptr_to32;
     
     switch(var_type) {
     case VM_DATA_TYPE_INT64:
@@ -611,8 +611,8 @@
         *var_ptr_to_64 = *(uint64*)value_ptr;
         break;
     default:
-        var_ptr_to32 = (uint32*)(ebp + frame.local(var_num));
-        *var_ptr_to32 = *(uint32*)value_ptr;
+        var_ptr_to32 = (U_32*)(ebp + frame.local(var_num));
+        *var_ptr_to32 = *(U_32*)value_ptr;
     }
 
     return EXE_ERROR_NONE;
@@ -642,10 +642,10 @@
        //2. Replace all the remaining bytes of counter instruction with nops
        //3. Atomically replace jump with 2 nops
        U_8* methodAddr = method_get_code_block_jit(mh, jit);
-       for (uint32 i = 0 ; i<infoBlock.num_profiler_counters; i++) {
-           uint32 offsetInfo = infoBlock.profiler_counters_map[i];
-           uint32 codeOffset = ProfileCounterInfo::getInstOffset(offsetInfo);
-           uint32 patchedSize = ProfileCounterInfo::getInstSize(offsetInfo);
+       for (U_32 i = 0 ; i<infoBlock.num_profiler_counters; i++) {
+           U_32 offsetInfo = infoBlock.profiler_counters_map[i];
+           U_32 codeOffset = ProfileCounterInfo::getInstOffset(offsetInfo);
+           U_32 patchedSize = ProfileCounterInfo::getInstSize(offsetInfo);
 
            U_8* patchedAddr = methodAddr + codeOffset;
            //1. Generate jump to the next instruction

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/sconsts.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/sconsts.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/sconsts.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/sconsts.h Thu May 22 06:33:38 2008
@@ -111,7 +111,7 @@
      * @brief Address of helper that returns a pointer to 
         thread local struct.
      * @param none
-     * @return read-only pointer to an int32 flag.
+     * @return read-only pointer to an I_32 flag.
      */
     static char*        rt_helper_get_tls_base_ptr;
 

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/sframe.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/sframe.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/sframe.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/sframe.h Thu May 22 06:33:38 2008
@@ -149,7 +149,7 @@
  * number of registers is much bigger than on IA-32 and each register is
  * 8 bytes wide - so the spill area is long. As result, the length of 
  * the fixed-size area does not fit into +/-127. This makes generated code 
- * to use addressing with 32 bit displacements [rbp+int32] which make code 
+ * to use addressing with 32 bit displacements [rbp+I_32] which make code 
  * bigger. If we point base pointer (in the method's prolog) not to the 
  * beginning of the frame but, say, into the middle between 
  * locals and stack, then we'll be able to address most of them with 8bit 

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/main/Jitrino.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/main/Jitrino.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/main/Jitrino.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/main/Jitrino.cpp Thu May 22 06:33:38 2008
@@ -308,7 +308,7 @@
 
 #if defined(_WIN32) || defined(_WIN64)
 
-extern "C" bool __stdcall DllMain(void *dll_handle, uint32 reason, void *reserved) {
+extern "C" bool __stdcall DllMain(void *dll_handle, U_32 reason, void *reserved) {
 
     switch (reason) { 
     case DLL_PROCESS_ATTACH: 

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/main/Log.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/main/Log.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/main/Log.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/main/Log.cpp Thu May 22 06:33:38 2008
@@ -85,7 +85,7 @@
 #endif
 
 
-void Log::printStageBegin(std::ostream& out, uint32 stageId, const char * stageGroup, const char * stageName, const char * stageTag)
+void Log::printStageBegin(std::ostream& out, U_32 stageId, const char * stageGroup, const char * stageName, const char * stageTag)
 {
     out
         << "========================================================================" << ::std::endl
@@ -93,7 +93,7 @@
         << "========================================================================" << ::std::endl << ::std::endl ;
 }
 
-void Log::printStageEnd(std::ostream& out, uint32 stageId, const char * stageGroup, const char * stageName, const char * stageTag)
+void Log::printStageEnd(std::ostream& out, U_32 stageId, const char * stageGroup, const char * stageName, const char * stageTag)
 {
     out
         << "========================================================================" << ::std::endl
@@ -102,7 +102,7 @@
 }
 
 
-void Log::printIRDumpBegin(std::ostream& out, uint32 stageId, const char * stageName, const char * subKind)
+void Log::printIRDumpBegin(std::ostream& out, U_32 stageId, const char * stageName, const char * subKind)
 {
     out
         << "========================================================================" << ::std::endl
@@ -112,7 +112,7 @@
 }
 
 
-void Log::printIRDumpEnd(std::ostream& out, uint32 stageId, const char * stageName, const char * subKind)
+void Log::printIRDumpEnd(std::ostream& out, U_32 stageId, const char * stageName, const char * subKind)
 {
     out
         << "========================================================================" << ::std::endl

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/main/Log.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/main/Log.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/main/Log.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/main/Log.h Thu May 22 06:33:38 2008
@@ -67,10 +67,10 @@
 
 #endif
 
-    static void printStageBegin (std::ostream&, uint32 stageId, const char * stageGroup, const char * stageName, const char * stageTag);
-    static void printStageEnd   (std::ostream&, uint32 stageId, const char * stageGroup, const char * stageName, const char * stageTag);
-    static void printIRDumpBegin(std::ostream&, uint32 stageId, const char * stageName, const char * subKind);
-    static void printIRDumpEnd  (std::ostream&, uint32 stageId, const char * stageName, const char * subKind);
+    static void printStageBegin (std::ostream&, U_32 stageId, const char * stageGroup, const char * stageName, const char * stageTag);
+    static void printStageEnd   (std::ostream&, U_32 stageId, const char * stageGroup, const char * stageName, const char * stageTag);
+    static void printIRDumpBegin(std::ostream&, U_32 stageId, const char * stageName, const char * subKind);
+    static void printIRDumpEnd  (std::ostream&, U_32 stageId, const char * stageName, const char * subKind);
 
     static char* makeDotFileName (const char* suffix);
 

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/CSEHash.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/CSEHash.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/CSEHash.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/CSEHash.cpp Thu May 22 06:33:38 2008
@@ -28,9 +28,9 @@
 
 namespace Jitrino {
 
-uint32 HashTableImpl::numLookup = 0;
-uint32 HashTableImpl::numLookupEntry = 0;
-uint32 HashTableImpl::numFound = 0;
+U_32 HashTableImpl::numLookup = 0;
+U_32 HashTableImpl::numLookupEntry = 0;
+U_32 HashTableImpl::numFound = 0;
 
 Inst*    CSEHashTable::lookupKeyBase(CSEHashKey* key) {
     Inst* inst = (Inst*)hashTable.lookup(key);

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/CSEHash.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/CSEHash.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/CSEHash.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/CSEHash.h Thu May 22 06:33:38 2008
@@ -50,23 +50,23 @@
     CSEHashKey(CSEHashKey* key) {
         copy(key);
     }
-    CSEHashKey(uint32 opc) {
+    CSEHashKey(U_32 opc) {
         opcode = opc;
         opnd1 = opnd2 = opnd3 = 0;
     }
-    CSEHashKey(uint32 opc, uint32 opnd) {
+    CSEHashKey(U_32 opc, U_32 opnd) {
         opcode = opc; 
         opnd1 = opnd; 
         opnd2 = 0;
         opnd3 = 0;
     }
-    CSEHashKey(uint32 opc, uint32 op1, uint32 op2) {
+    CSEHashKey(U_32 opc, U_32 op1, U_32 op2) {
         opcode = opc;
         opnd1 = op1;
         opnd2 = op2;
         opnd3 = 0;
     }
-    CSEHashKey(uint32 opc, uint32 op1, uint32 op2, uint32 op3) {
+    CSEHashKey(U_32 opc, U_32 op1, U_32 op2, U_32 op3) {
         opcode = opc;
         opnd1 = op1;
         opnd2 = op2;
@@ -114,7 +114,7 @@
         return compare(other)>=0;
     }
 
-    uint32 getHashCode() const {
+    U_32 getHashCode() const {
         return opcode + (opnd1 ^ opnd2) + opnd3;
     }
     void copy(const CSEHashKey* key) {
@@ -132,15 +132,15 @@
            << (int) opnd3 << ")";
     }
 private:
-    uint32   opcode;
-    uint32   opnd1;
-    uint32   opnd2;
-    uint32   opnd3;
+    U_32   opcode;
+    U_32   opnd1;
+    U_32   opnd2;
+    U_32   opnd3;
 };
 
 class CSEHash : public KeyLinkHashTable<CSEHashKey> {
 public:
-    CSEHash(MemoryManager& mm, uint32 size) : KeyLinkHashTable<CSEHashKey>(mm, size) {}
+    CSEHash(MemoryManager& mm, U_32 size) : KeyLinkHashTable<CSEHashKey>(mm, size) {}
 };
 
 #define CSE_NUM_HASH_LINKS 32
@@ -148,7 +148,7 @@
 
 class FixedCSEHash : public FixedKeyLinkHashTable<CSEHashKey, CSE_NUM_HASH_LINKS> {
 public:
-    FixedCSEHash(MemoryManager& mm, uint32 size) 
+    FixedCSEHash(MemoryManager& mm, U_32 size) 
         : FixedKeyLinkHashTable<CSEHashKey, CSE_NUM_HASH_LINKS>(mm, size) {}
 };
 
@@ -162,46 +162,46 @@
     void    kill() {hashTable.removeAll();}
     virtual Inst*  lookupKey(CSEHashKey* key) { return lookupKeyBase(key); }
 
-    Inst*    lookup(uint32 opc) {
+    Inst*    lookup(U_32 opc) {
         CSEHashKey key(opc);            
         return lookupKey(&key);
     }
-    Inst*    lookup(uint32 opc, uint32 op1) {
+    Inst*    lookup(U_32 opc, U_32 op1) {
         CSEHashKey key(opc, op1);        
         return lookupKey(&key);
     }
-    Inst*    lookup(uint32 opc, uint32 op1, uint32 op2) {
+    Inst*    lookup(U_32 opc, U_32 op1, U_32 op2) {
         CSEHashKey key(opc, op1, op2);    
         return lookupKey(&key);
     }
-    Inst*    lookup(uint32 opc, uint32 op1, uint32 op2, uint32 op3) {
+    Inst*    lookup(U_32 opc, U_32 op1, U_32 op2, U_32 op3) {
         CSEHashKey key(opc, op1, op2, op3);
         return lookupKey(&key);
     }
-    void    remove(uint32 opc, uint32 op1) {
+    void    remove(U_32 opc, U_32 op1) {
         CSEHashKey key(opc, op1);
         hashTable.remove(&key);
     }
-    void    insert(uint32 opc, Inst* inst) {
+    void    insert(U_32 opc, Inst* inst) {
         CSEHashKey key(opc);            
         hashTable.insert(&key, inst);
     }
-    void    insert(uint32 opc, uint32 op1, Inst* inst) {
+    void    insert(U_32 opc, U_32 op1, Inst* inst) {
         CSEHashKey key(opc, op1);        
         hashTable.insert(&key, inst);
     }
-    void    insert(uint32 opc, uint32 op1, uint32 op2, Inst* inst) {
+    void    insert(U_32 opc, U_32 op1, U_32 op2, Inst* inst) {
         CSEHashKey key(opc, op1, op2);    
         hashTable.insert(&key, inst);
     }
-    void    insert(uint32 opc, uint32 op1, uint32 op2, uint32 op3, Inst* inst) {
+    void    insert(U_32 opc, U_32 op1, U_32 op2, U_32 op3, Inst* inst) {
         CSEHashKey key(opc, op1, op2, op3);    
         hashTable.insert(&key, inst);
     }
     void    insert(CSEHashKey key, Inst* inst) {
         hashTable.insert(&key, inst);
     }
-    uint32  numCSE;
+    U_32  numCSE;
 
 protected:
     Inst*  lookupKeyBase(CSEHashKey* key);

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/CodeSelectors.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/CodeSelectors.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/CodeSelectors.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/CodeSelectors.cpp Thu May 22 06:33:38 2008
@@ -56,9 +56,9 @@
     }
 }
 
-uint32 _VarCodeSelector::getNumVarOpnds() {
+U_32 _VarCodeSelector::getNumVarOpnds() {
     VarOpnd* v0 = varOpnds;
-    uint32 numVars = 0;
+    U_32 numVars = 0;
     if (v0) {
         VarOpnd* v = v0;
         do {
@@ -410,19 +410,19 @@
     return JitHelperCallOp::InitializeArray; // to keep compiler quiet
 }
     
-CG_OpndHandle ** _BlockCodeSelector::genCallArgs(Inst * call, uint32 arg0Pos) {
-    uint32 nSrc = call->getNumSrcOperands();
+CG_OpndHandle ** _BlockCodeSelector::genCallArgs(Inst * call, U_32 arg0Pos) {
+    U_32 nSrc = call->getNumSrcOperands();
     CG_OpndHandle ** args = new(memManager) CG_OpndHandle*[nSrc - arg0Pos];
-    for (uint32 i = arg0Pos; i < nSrc; i++)
+    for (U_32 i = arg0Pos; i < nSrc; i++)
         args[i - arg0Pos] = getCGInst(call->getSrc(i));
     return args;
 }
     
-CG_OpndHandle ** _BlockCodeSelector::genCallArgs(Opnd *extraArg, Inst * call, uint32 arg0Pos) {
-    uint32 nSrc = call->getNumSrcOperands();
+CG_OpndHandle ** _BlockCodeSelector::genCallArgs(Opnd *extraArg, Inst * call, U_32 arg0Pos) {
+    U_32 nSrc = call->getNumSrcOperands();
     CG_OpndHandle ** args = new(memManager) CG_OpndHandle*[nSrc - arg0Pos + 1];
     args[0] = getCGInst(extraArg);
-    for (uint32 i = arg0Pos; i < nSrc; i++)
+    for (U_32 i = arg0Pos; i < nSrc; i++)
         args[i - arg0Pos + 1] = getCGInst(call->getSrc(i));
     return args;
 }
@@ -637,7 +637,7 @@
                 ConstInst *op1ci = op1->getInst()->asConstInst();
                 assert(op1ci);
                 assert(op1ci->getType() == Type::Int32);
-                int32 shiftby = op1ci->getValue().i4;
+                I_32 shiftby = op1ci->getValue().i4;
                 cgInst = instructionCallback.shladd(mapToIntegerOpType(inst),
                     getCGInst(inst->getSrc(0)),
                     shiftby,
@@ -783,7 +783,7 @@
                 MethodCallInst * call = (MethodCallInst *)inst;
                 MethodDesc * methodDesc = call->getMethodDesc();
                 CG_OpndHandle ** args = genCallArgs(call,2); // omit tau operands
-                uint32 numArgs = inst->getNumSrcOperands()-2; // also omit from count
+                U_32 numArgs = inst->getNumSrcOperands()-2; // also omit from count
                 cgInst = 
                     instructionCallback.tau_call(numArgs,
                                                  args,
@@ -903,7 +903,7 @@
         case Op_ThrowSystemException:
             {
                 TokenInst *tokenInst = (TokenInst *)inst;
-                uint32 token = tokenInst->getToken();
+                U_32 token = tokenInst->getToken();
                 CompilationInterface::SystemExceptionId id 
                     = (CompilationInterface::SystemExceptionId)token;
                 instructionCallback.throwSystemException(id);
@@ -913,8 +913,8 @@
             {
                 LinkingExcInst *linkExcInst = (LinkingExcInst *)inst;
                 Class_Handle encClass = linkExcInst->getEnclosingClass();
-                uint32 constPoolIndex = linkExcInst->getCPIndex();
-                uint32 opcode = linkExcInst->getOperation();
+                U_32 constPoolIndex = linkExcInst->getCPIndex();
+                U_32 opcode = linkExcInst->getOperation();
                 instructionCallback.throwLinkingException(encClass, constPoolIndex, opcode);
             }
             break;
@@ -987,7 +987,7 @@
                 AutoCompressModifier acmod = inst->getAutoCompressModifier();
 
                 TokenInst *tokenInst = (TokenInst *)inst;
-                uint32 token = tokenInst->getToken();
+                U_32 token = tokenInst->getToken();
                 cgInst = instructionCallback.ldRef(inst->getDst()->getType(),
                     tokenInst->getEnclosingMethod(),
                     token, acmod==AutoCompress_Yes);
@@ -1588,9 +1588,9 @@
             {
                 Type * arrayType = inst->getDst()->getType();
                 assert(arrayType->isArrayType());
-                uint32 numDims = inst->getNumSrcOperands();
+                U_32 numDims = inst->getNumSrcOperands();
                 CG_OpndHandle ** dims = new(memManager) CG_OpndHandle*[numDims];
-                for (uint32 i = 0; i < numDims; i++) 
+                for (U_32 i = 0; i < numDims; i++) 
                     dims[i] = getCGInst(inst->getSrc(i));
                 cgInst = instructionCallback.newMultiArray((ArrayType*)arrayType,
                     numDims,
@@ -1806,7 +1806,7 @@
             {
                 Type* type = inst->asTypeInst()->getTypeInfo();
                 assert(type->isValueType());
-                uint32 size = ((UserValueType*) type)->getUnboxedSize();
+                U_32 size = ((UserValueType*) type)->getUnboxedSize();
                 instructionCallback.ldc_i4(size);
             }
             break;
@@ -1831,7 +1831,7 @@
                 assert(inst->getNumSrcOperands() == 0);
                 if (!genConsts) break;
                 TokenInst *tokenInst = (TokenInst *)inst;
-                uint32 token = tokenInst->getToken();
+                U_32 token = tokenInst->getToken();
                 cgInst = instructionCallback.ldToken(inst->getDst()->getType(),
                     tokenInst->getEnclosingMethod(), token);
                 isConstant = true;
@@ -1871,7 +1871,7 @@
         case Op_IncCounter:
             {
                 TokenInst *counterInst = (TokenInst *)inst;
-                uint32 counter = counterInst->getToken();
+                U_32 counter = counterInst->getToken();
                 instructionCallback.incCounter(irmanager.getTypeManager().getUInt32Type(), counter);
             }
             break;
@@ -1896,7 +1896,7 @@
             break;
         case Op_TauAnd:
             {
-                uint32 numSrcs = inst->getNumSrcOperands();
+                U_32 numSrcs = inst->getNumSrcOperands();
                 CG_OpndHandle **args = genCallArgs(inst, 0);
                 cgInst = instructionCallback.tauAnd(numSrcs, args);
             }
@@ -2048,7 +2048,7 @@
         callback->opndMaybeGlobal(inst);
 }
 
-uint32 _BlockCodeSelector::getVarHandle(VarOpnd *var) {
+U_32 _BlockCodeSelector::getVarHandle(VarOpnd *var) {
     return varIdMap[var->getId()];
 }
 
@@ -2066,7 +2066,7 @@
     // node id returned by the code selector
     //
     StlVector<MethodDesc*> inlineEndMarkers(memManager);
-    uint32*    nodeMapTable = new (memManager) uint32[numNodes];
+    U_32*    nodeMapTable = new (memManager) U_32[numNodes];
     
     // Compute postorder list to get only reachable nodes.
     const Nodes& nodes = flowGraph->getNodesPostOrder();
@@ -2081,9 +2081,9 @@
         //
         // Count in and out edges
         //
-        uint32 numOutEdges = node->getOutDegree();
-        uint32 numInEdges = node->getInDegree();
-        uint32 nodeId = MAX_UINT32;
+        U_32 numOutEdges = node->getOutDegree();
+        U_32 numInEdges = node->getInDegree();
+        U_32 nodeId = MAX_UINT32;
         double cnt = (hasEdgeProfile? node->getExecCount() : -1.0);
 
         if (node == exit) {
@@ -2140,18 +2140,18 @@
     for(niter = nodes.rbegin(); niter != nodes.rend(); ++niter) {
         double    prob;
         Node* tailNode = *niter;
-        uint32 tailNodeId = nodeMapTable[tailNode->getDfNum()];
+        U_32 tailNodeId = nodeMapTable[tailNode->getDfNum()];
         if (((Inst*)tailNode->getLastInst())->isSwitch()) { 
             //
             //  Generate switch edges
             //
             SwitchInst* sw = (SwitchInst *)tailNode->getLastInst();
             Node *defaultNode = sw->getDefaultTarget()->getNode();
-            uint32 defaultNodeId = nodeMapTable[defaultNode->getDfNum()];
-            uint32 numTargets = sw->getNumTargets();
-            uint32 * targetNodeIds = new (memManager) uint32[numTargets];
+            U_32 defaultNodeId = nodeMapTable[defaultNode->getDfNum()];
+            U_32 numTargets = sw->getNumTargets();
+            U_32 * targetNodeIds = new (memManager) U_32[numTargets];
             double * targetProbs = new (memManager) double[numTargets];
-            uint32 i;
+            U_32 i;
             for (i = 0; i < numTargets; i++) {
                 Node *headNode = sw->getTarget(i)->getNode();
                 Edge *edge = (Edge *) tailNode->findTargetEdge(headNode);
@@ -2168,7 +2168,7 @@
                 assert(0);
                 Node *succNode = throwEdge->getTargetNode();
                 assert(succNode->isDispatchNode());
-                uint32 headNodeId = nodeMapTable[succNode->getDfNum()];
+                U_32 headNodeId = nodeMapTable[succNode->getDfNum()];
                 prob = (hasEdgeProfile? throwEdge->getEdgeProb() : -1.0);
                 callback.genExceptionEdge(tailNodeId,headNodeId,prob);
             }
@@ -2183,7 +2183,7 @@
                 Edge* edge = *eiter;
                 prob = (hasEdgeProfile? edge->getEdgeProb() : -1.0);
                 Node * headNode = edge->getTargetNode();
-                uint32 headNodeId = nodeMapTable[headNode->getDfNum()];
+                U_32 headNodeId = nodeMapTable[headNode->getDfNum()];
                 Edge::Kind edgeKind = edge->getKind();
                 switch (edgeKind) {
                     case Edge::Kind_Unconditional:
@@ -2223,8 +2223,8 @@
 
     callback.setMethodDesc(methodDesc);
 
-    uint32 *varIdMap = new (localMemManager) uint32[numVars];
-    uint32 i;
+    U_32 *varIdMap = new (localMemManager) U_32[numVars];
+    U_32 i;
     for (i = 0; i < numVars; i++) {
         varIdMap[i] = 0;
     }

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/CodeSelectors.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/CodeSelectors.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/CodeSelectors.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/CodeSelectors.h Thu May 22 06:33:38 2008
@@ -35,23 +35,23 @@
 
 class _VarCodeSelector : public VarCodeSelector {
 public:
-    _VarCodeSelector(VarOpnd* opnds, uint32* varMap, GCBasePointerMap& gcMap) 
+    _VarCodeSelector(VarOpnd* opnds, U_32* varMap, GCBasePointerMap& gcMap) 
         : varOpnds(opnds), varIdMap(varMap), gcMap(gcMap)
     {}
 
     void genCode(Callback& callback);
-    uint32 getNumVarOpnds();
+    U_32 getNumVarOpnds();
 
 private:
     VarOpnd* varOpnds;
-    uint32*  varIdMap;
+    U_32*  varIdMap;
     GCBasePointerMap& gcMap;
 };
 
 class _BlockCodeSelector : public BlockCodeSelector {
 public:
     _BlockCodeSelector(MemoryManager& mm, IRManager& irmanager, Node* b,CG_OpndHandle** map,
-        uint32* varMap, bool sinkConstants0, bool sinkConstantsOne0) 
+        U_32* varMap, bool sinkConstants0, bool sinkConstantsOne0) 
         : irmanager(irmanager), memManager(mm), opndToCGInstMap(map), 
         localOpndToCGInstMap(mm), varIdMap(varMap), block(b),
         sinkConstants(sinkConstants0), sinkConstantsOne(sinkConstantsOne0), argCount(0)
@@ -106,9 +106,9 @@
 
     JitHelperCallOp::Id convertJitHelperId(JitHelperCallId callId);
 
-    CG_OpndHandle ** genCallArgs(Inst * call, uint32 arg0Pos);
+    CG_OpndHandle ** genCallArgs(Inst * call, U_32 arg0Pos);
 
-    CG_OpndHandle ** genCallArgs(Opnd *extraArg, Inst * call, uint32 arg0Pos);
+    CG_OpndHandle ** genCallArgs(Opnd *extraArg, Inst * call, U_32 arg0Pos);
 
     void genInstCode(InstructionCallback& instructionCallback, Inst *inst, bool genConsts);
     
@@ -119,24 +119,24 @@
     void setLocalCGInst(CG_OpndHandle* inst, Opnd* opnd);
     void clearLocalCGInsts();
     void setCGInst(CG_OpndHandle* inst,Opnd* opnd);
-    uint32 getVarHandle(VarOpnd *var);
+    U_32 getVarHandle(VarOpnd *var);
 
     IRManager&              irmanager;
     MemoryManager&          memManager;
     CG_OpndHandle**         opndToCGInstMap;
-    StlMap<uint32, CG_OpndHandle*> localOpndToCGInstMap;
-    uint32*                 varIdMap;
+    StlMap<U_32, CG_OpndHandle*> localOpndToCGInstMap;
+    U_32*                 varIdMap;
     Node*                   block;
     InstructionCallback*    callback;
     bool                    sinkConstants;
     bool                    sinkConstantsOne;
-    uint32                  argCount;
+    U_32                  argCount;
 };
 
 class _CFGCodeSelector : public CFGCodeSelector {
 public:
     _CFGCodeSelector(MemoryManager& mm, IRManager& irmanager, ControlFlowGraph* fg,CG_OpndHandle** map,
-                     uint32 *varMap, bool sinkConstants0, bool sinkConstantsOne0)
+                     U_32 *varMap, bool sinkConstants0, bool sinkConstantsOne0)
         : irmanager(irmanager), opndToCGInstMap(map), varIdMap(varMap), 
           flowGraph(fg), numNodes(0), memManager(mm), sinkConstants(sinkConstants0),
           sinkConstantsOne(sinkConstantsOne0)
@@ -145,13 +145,13 @@
         numNodes = flowGraph->getNodeCount();
     }
     void genCode(Callback& callback); 
-    uint32 getNumNodes() {return numNodes;}
+    U_32 getNumNodes() {return numNodes;}
 private:
     IRManager&         irmanager;
     CG_OpndHandle**    opndToCGInstMap;
-    uint32*            varIdMap;
+    U_32*            varIdMap;
     ControlFlowGraph*  flowGraph;
-    uint32            numNodes;
+    U_32            numNodes;
     MemoryManager&    memManager;
     bool              sinkConstants;
     bool              sinkConstantsOne;
@@ -174,9 +174,9 @@
     void selectCode(Callback& callback);
 private:
     IRManager&  irmanager;
-    uint32      numOpnds;
-    uint32      numArgs;
-    uint32      numVars;
+    U_32      numOpnds;
+    U_32      numArgs;
+    U_32      numVars;
     VarOpnd*    varOpnds;
     ControlFlowGraph*  flowGraph;
     MethodDesc* methodDesc;

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/FastArrayFilling.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/FastArrayFilling.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/FastArrayFilling.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/FastArrayFilling.cpp Thu May 22 06:33:38 2008
@@ -132,18 +132,18 @@
     /* Code pattern:
 
     label .node1
-    arraylen  arrayRef ((tau1,tau3)) -) arrayBound:int32
+    arraylen  arrayRef ((tau1,tau3)) -) arrayBound:I_32
     chkub 0 .lt. arrayBound -) tau2:tau
     GOTO .node2
 
     label .node2
     ldbase    arrayRef -) arrayBase:ref:char
     stind.unc:chr constValue ((tau1,tau2,tau3)) -) [arrayBase]
-    stvar     startIndex -) index:int32
+    stvar     startIndex -) index:I_32
     GOTO .loopNode1
 
     label .loopNode1
-    ldvar     index -) tmpIndex:int32
+    ldvar     index -) tmpIndex:I_32
     if cge.i4  tmpIndex, fillBound goto .loopExit
     GOTO .node2
 
@@ -154,8 +154,8 @@
     label .loopNode3
     addindex  arrayBase, tmpIndex -) address:ref:char
     stind.unc:chr constValue ((tau1,tau2,tau3)) -) [address]
-    add   tmpIndex, addOp -) inc:int32
-    stvar     inc -) index:int32
+    add   tmpIndex, addOp -) inc:I_32
+    stvar     inc -) index:I_32
     GOTO .node1
     
     */
@@ -283,7 +283,7 @@
 #ifdef _EM64T_
         int64 val = (int64)((ConstInst*)constValue->getInst())->getValue().i8;
 #else
-        int32 val = (int32)((ConstInst*)constValue->getInst())->getValue().i4;
+        I_32 val = (I_32)((ConstInst*)constValue->getInst())->getValue().i4;
 #endif
         switch (((Type*)arrayRef->getType()->asArrayType()->getElementType())->tag) {
             case Type::Int8:

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/FlowGraph.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/FlowGraph.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/FlowGraph.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/FlowGraph.cpp Thu May 22 06:33:38 2008
@@ -53,7 +53,7 @@
 }
 
 void         
-FlowGraph::foldSwitch(ControlFlowGraph& fg, SwitchInst* sw, uint32 index)
+FlowGraph::foldSwitch(ControlFlowGraph& fg, SwitchInst* sw, U_32 index)
 {
     Node* block = sw->getNode();
     assert(sw == block->getLastInst());
@@ -140,8 +140,8 @@
         newblock->appendInst(newInst);
         if(Log::isEnabled()) {
             Log::out() << "          ";
-            Log::out() << (int32)inst->getNumSrcOperands();
-            Log::out() << " " << (int32)inst->getOpcode() << " ";
+            Log::out() << (I_32)inst->getNumSrcOperands();
+            Log::out() << " " << (I_32)inst->getOpcode() << " ";
             newInst->print(Log::out());
             Log::out() << "\n";
             Log::out().flush();
@@ -366,7 +366,7 @@
 Inst* FlowGraph::findPhi(Node* node, Opnd** opnds, int opndsCount) {
     
     for (Inst* inst = (Inst*)node->getFirstInst(); inst != NULL; inst = inst->getNextInst()) {        
-        if (inst->getOpcode() == Op_Phi && inst->getNumSrcOperands() == (uint32)opndsCount) {
+        if (inst->getOpcode() == Op_Phi && inst->getNumSrcOperands() == (U_32)opndsCount) {
             for (int i = 0; i < opndsCount; i++) {
                 if (inst->getSrc(i) != opnds[i]) {
                     break;
@@ -450,8 +450,8 @@
 void FlowGraph::renameOperandsInNode(Node *node, OpndRenameTable *renameTable) {
     Inst *first = (Inst*)node->getFirstInst();
     for (Inst *inst = first->getNextInst(); inst != NULL; inst = inst->getNextInst()) {
-        uint32 n = inst->getNumSrcOperands();
-        for(uint32 i = 0; i < n; ++i) {
+        U_32 n = inst->getNumSrcOperands();
+        for(U_32 i = 0; i < n; ++i) {
             Opnd* src = inst->getSrc(i);
             Opnd* newsrc = renameTable->getMapping(src);
             if(newsrc != NULL)
@@ -727,7 +727,7 @@
     //std::reverse(nodes.begin(), nodes.end());
     //WARN: new nodes created during the iteration 
     //we use the fact that new nodes added to the end of the collection here.
-    for (uint32 idx = 0; idx < nodes.size(); ++idx) {
+    for (U_32 idx = 0; idx < nodes.size(); ++idx) {
         Node* node = nodes[idx];
         Inst* last = (Inst*)node->getLastInst();
         if(last->isJSR()) {
@@ -736,7 +736,7 @@
     }
 #ifdef _DEBUG
     const Nodes& nnodes = fg.getNodes();
-    for (uint32 idx = 0; idx < nnodes.size(); ++idx) {
+    for (U_32 idx = 0; idx < nnodes.size(); ++idx) {
         Node* node = nnodes[idx];
         Inst* last = (Inst*)node->getLastInst();
         assert(!last->isJSR());
@@ -893,7 +893,7 @@
 }
 
 void FlowGraph::doTranslatorCleanupPhase(IRManager& irm) {
-    uint32 id = irm.getCompilationContext()->getCurrentSessionNum();
+    U_32 id = irm.getCompilationContext()->getCurrentSessionNum();
     const char* stage = "trans_cleanup";
     if (Log::isLogEnabled(LogStream::IRDUMP)) {
         LogStream& irdump = Log::log(LogStream::IRDUMP);
@@ -1163,13 +1163,13 @@
         if(node->getOutDegree() == 1 && node->getOutEdges().front()->getTargetNode()->isExitNode())
             cout << "UNWIND";
         else
-            cout << "D" << (int32)((LabelInst*)first)->getLabelId();
+            cout << "D" << (I_32)((LabelInst*)first)->getLabelId();
     } else {
         cout << "EXIT";
     }
 }
 
-void FlowGraph::printInsts(std::ostream& cout, Node* node, uint32 indent){
+void FlowGraph::printInsts(std::ostream& cout, Node* node, U_32 indent){
     std::string indentstr(indent, ' ');
     Inst* inst = (Inst*)node->getFirstInst();
     while (inst!=NULL) {

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/FlowGraph.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/FlowGraph.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/FlowGraph.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/FlowGraph.h Thu May 22 06:33:38 2008
@@ -59,7 +59,7 @@
     // from block.
     static void  foldBranch(ControlFlowGraph& fg, BranchInst* br, bool isTaken);
 
-    static void  foldSwitch(ControlFlowGraph& fg, SwitchInst* sw, uint32 target);
+    static void  foldSwitch(ControlFlowGraph& fg, SwitchInst* sw, U_32 target);
 
     // Eliminates the check at the end of block and the associated exception
     // edge.  If (alwaysThrows), then eliminates the non-exception edge instead;
@@ -81,7 +81,7 @@
     static void print(std::ostream& cout, Node* node);
     static void printLabel(std::ostream& cout, Node* node);
     static void printLabel(std::ostream& cout, DominatorNode* dNode) {printLabel(cout, dNode->getNode()); }
-    static void printInsts(std::ostream& cout, Node* node, uint32 indent);
+    static void printInsts(std::ostream& cout, Node* node, U_32 indent);
 
     static void printDotFile(ControlFlowGraph& cfg, MethodDesc& methodDesc,const char *suffix);
 
@@ -114,7 +114,7 @@
 public:
     typedef HashTableIter<Node, Node> Iter;
 
-    NodeRenameTable(MemoryManager& mm,uint32 size):HashTable<Node,Node>(mm,size) {}
+    NodeRenameTable(MemoryManager& mm,U_32 size):HashTable<Node,Node>(mm,size) {}
     Node *getMapping(Node *node) { return (Node*)lookup(node);  }
     void     setMapping(Node *node, Node *to) { insert(node,to); }
 
@@ -122,7 +122,7 @@
     virtual bool keyEquals(Node* key1,Node* key2) const { return key1 == key2; }
     
     // return hash of address bits
-    virtual uint32 getKeyHashCode(Node* key) const { return ((uint32)(((POINTER_SIZE_INT)key) >> sizeof(void*))); }
+    virtual U_32 getKeyHashCode(Node* key) const { return ((U_32)(((POINTER_SIZE_INT)key) >> sizeof(void*))); }
 };
 
 } //namespace Jitrino 

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/HLOAPIMagics.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/HLOAPIMagics.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/HLOAPIMagics.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/HLOAPIMagics.cpp Thu May 22 06:33:38 2008
@@ -716,7 +716,7 @@
 }
 
 Opnd*
-HLOAPIMagicIRBuilder::genLdConstant(int32 val) {
+HLOAPIMagicIRBuilder::genLdConstant(I_32 val) {
     Opnd* dst = createOpnd(typeManager.getInt32Type());
     appendInst(instFactory.makeLdConst(dst, val));
     return dst;

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/HLOAPIMagics.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/HLOAPIMagics.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/HLOAPIMagics.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/optimizer/HLOAPIMagics.h Thu May 22 06:33:38 2008
@@ -75,7 +75,7 @@
     Opnd* genTauAnd(Opnd* src1, Opnd* src2);
     Opnd* genAdd(Type* dstType, Modifier mod, Opnd* src1, Opnd* src2);
     Opnd* genSub(Type* dstType, Modifier mod, Opnd* src1, Opnd* src2);
-    Opnd* genLdConstant(int32 val);
+    Opnd* genLdConstant(I_32 val);
     Opnd* genArrayLen(Type* dstType, Type::Tag type, Opnd* array, Opnd* tauNonNull);
     Opnd* genTauArrayLen(Type* dstType, Type::Tag type, Opnd* array,
                          Opnd* tauNullChecked, Opnd *tauTypeChecked);
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/enc.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/enc.h Thu May 22 06:33:38 2008
@@ -125,8 +125,8 @@
      */
     void    ip(char * _ip)
     {
-        assert((uint32)(_ip - m_buf) == (uint64)(_ip - m_buf));
-        m_size = (uint32)(_ip - m_buf);
+        assert((U_32)(_ip - m_buf) == (uint64)(_ip - m_buf));
+        m_size = (U_32)(_ip - m_buf);
         assert(m_size < total_size);
         // Need to be done here, and not in ip(void).
         // Otherwise, the following usage template:
@@ -792,7 +792,7 @@
  *  - FR reg may hold both #dbl64 and #flt32
  *  - FR operations may have either memory or FR reg as second operand, but 
  *  not immediate
  *  - GR reg is wide enough to carry int32
  *  - GR reg is wide enough to carry a memory address
  *  - a memory may be addressed using complex address form cosists of 
  *      base and index registers, displacement and a scale for index. The 
@@ -988,7 +988,7 @@
    /**
    * Generates n-byte long NOP instruction.
    */
-    void nop(uint32 n) {
+    void nop(U_32 n) {
         if (is_trace_on()) {
             trace(string("nop"), to_str((int)n), string());
         }
@@ -1475,7 +1475,7 @@
     /// Implementation of alu().
     void alu_impl(ALU op, const Opnd& op0, const Opnd& op1);
    //Implementation of nop()
-    void nop_impl(uint32 n);
+    void nop_impl(U_32 n);
     /// Implementation of cmovcc().
     void cmovcc_impl(COND c, const Opnd& op0, const Opnd& op1);
     /// Implementation of cmpxchg().
@@ -792,7 +792,7 @@
  *  - FR operations may have either memory or FR reg as second operand, but 
  *  not immediate
- *  - GR reg is wide enough to carry int32
+ *  - GR reg is wide enough to carry I_32
  *  - GR reg is wide enough to carry a memory address
  *  - a memory may be addressed using complex address form cosists of 

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/enc_ia32.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/jet/enc_ia32.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================